.. Starbear documentation master file, created by
   sphinx-quickstart on Sun Jan 22 14:28:50 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Starbear's documentation!
====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   intro.rst
   tutorial.rst



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
